/*
 * File         : BV_AudioApp.h
 * Author       : Tomasz Stachowiak
 * Created      : Fri Jul 24 18:00:46 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#ifndef __BV_AUDIOAPP_H
#define __BV_AUDIOAPP_H

#include "BV.h"
#include "BV_Session_Control.h"
#include "BV_Application.h"
#include "BV_AudioPlay.h"
#include "BV_AudioCapture.h"
#include "BV_AudioCapThread.h"
#include "adpcm.h"
#include "gsm.h"

#define START 10
#define ADPCM 13
#define GSM 14
#define PCM 15
#define STOP 19

#define BASIC_AUDIO_SIZE 160
#define AUDIO_CHUNKS_NO 5

class BV_AudioApp : public BV_Application
{
 public:
  BV_AudioApp();
  ~BV_AudioApp();
  int process_message(RTPheader *header, char *body, int len);
  int send_audio();
  void update_options(Options *options);
  void play();
  void stop();

 protected:

  int playADPCM(int mbr, char *data, int len);
  int playGSM(int mbr, char *data, int len);
  int sendPCM();
  int sendADPCM();
  int sendGSM();
  short get_level(char *buffer, int no);

  BV_AudioPlay *ports[100];
  BV_AudioCapture *mic_port_;
  gsm gsm_handle_;
  int state_;
  int compression_;
  int mic_cutoff;
  BV_AudioCapThread *cap_thread_;
  struct adpcm_state adpcmsendstate;
  
  BV_Session_Control *session_;
  void *main_form_;
};

#endif


